@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: debugger.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: debugger.cpp 8293 2010-04-22 11:33:16Z dpage $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -114,6 +114,10 @@ bool debuggerFactory::CheckEnable(pgObject *obj)
     if (!obj->GetServer() || !(obj->GetServer()->GetSuperUser() || obj->GetServer()->GetUsername() == obj->GetOwner()))
         return false;
 
+    // EnterpriseDB 8.3 or earlier does not support debugging by the non-superuser
+    if (!obj->GetServer()->GetSuperUser() && !obj->GetConnection()->EdbMinimumVersion(8, 4))
+        return false;
+
     if (!obj->IsCollection())
     {
         switch (obj->GetMetaType())
