@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgDirectDbg.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgDirectDbg.cpp 8354 2010-05-12 09:35:22Z dpage $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -583,7 +583,8 @@ void dlgDirectDbg::invokeTargetCallable()
 {
     dbgPgParams *params = new dbgPgParams();
 
-    wxString query = wxT("CALL ") + m_targetInfo->getFQName() + wxT("(");
+    wxString query = m_targetInfo->getIsFunction() ? wxT("PERFORM ") : wxT("EXEC ");
+    query += m_targetInfo->getFQName() + wxT("(");
 
     // Setup the param struct.
     params->nParams = m_targetInfo->getArgCount();
@@ -653,12 +654,18 @@ void dlgDirectDbg::invokeTargetCallable()
 
 void dlgDirectDbg::invokeTargetStatement()
 {
-    wxString query( m_targetInfo->getIsFunction() ? wxT( "SELECT " ) : wxT( "EXEC " ));
+    wxString query = wxT("SELECT ");
+    wxString declareStatement;
+
+    if (!m_targetInfo->getIsFunction())
+        query = wxT("EXEC ");
+    else if (m_targetInfo->getLanguage() == wxT("edbspl"))
+        query = wxT("PERFORM ");
 
     // If this is a function, and the return type is not record, or 
     // we have at least one OUT/INOUT param, we should select from
     // the function to get a full resultset.
-    if (m_targetInfo->getIsFunction() &&
+    if (m_targetInfo->getIsFunction() && m_targetInfo->getLanguage() != wxT("edbspl") &&
         (m_targetInfo->getReturnType() != wxT("record") || 
          m_targetInfo->getArgInOutCount() > 0 ||
          m_targetInfo->getArgOutCount() > 0))
@@ -674,14 +681,23 @@ void dlgDirectDbg::invokeTargetStatement()
     {
         wsArgInfo & arg = (*m_targetInfo)[i];
 
-        if(arg.getMode() == wxT("o"))
+        if(arg.getMode() == wxT("o") || arg.getMode() == wxT("b"))
         {
             if (!m_targetInfo->getIsFunction() || m_targetInfo->getLanguage() == wxT("edbspl"))
-                query.Append( wxT("NULL::") + arg.getType() + wxT(", "));
+            {
+                wxString strParam = wxString::Format(wxT("param%d"), i);
+                declareStatement +=  strParam + wxT(" ") + arg.getType();
+                if (arg.getMode() == wxT("b"))
+                    declareStatement += wxT(" ") + arg.quoteValue() + wxT("::") + arg.getType();
+                declareStatement += wxT(";\n");
+                query.Append(strParam + wxT(", "));
+            }
+            else
+                query.Append( arg.quoteValue() + wxT("::") + arg.getType() + wxT(", "));
         }
         else if(arg.getMode() == wxT("v"))
-			query.Append( arg.getValue() + wxT(", "));
-		else
+            query.Append( arg.getValue() + wxT(", "));
+        else
             query.Append( arg.quoteValue() + wxT("::") + arg.getType() + wxT(", "));
 			
     }
@@ -702,6 +718,16 @@ void dlgDirectDbg::invokeTargetStatement()
         query.Append( wxT( ")" ));
     }
 
+    if (!m_targetInfo->getIsFunction() || m_targetInfo->getLanguage() == wxT("edbspl"))
+    {
+        wxString tmpQuery = wxT("DECLARE\n")
+                          + declareStatement
+                          + wxT("BEGIN\n")
+                          + query + wxT(";\n")
+                          + wxT("END;");
+        query = tmpQuery;
+    }
+
     // And send the completed command to the server - we'll get 
     // a dbgDbResult event when the command completes (and that 
     // event will get routed to dlgDirectDbg::OnResultReady())
@@ -741,7 +767,7 @@ void dlgDirectDbg::OnTargetComplete( wxCommandEvent & event )
         char *state = PQresultErrorField(result,PG_DIAG_SQLSTATE);
 
         // Don't bother telling the user that he aborted - he already knows!
-        if (strcmp(state, "57014"))
+        if (state != NULL && strcmp(state, "57014"))
             wxLogError( wxT( "%s\n" ), wxString(PQerrorMessage(m_conn->getConnection()), wxConvUTF8).c_str());
         else
             wxLogInfo( wxT( "%s\n" ), wxString(PQerrorMessage(m_conn->getConnection()), wxConvUTF8).c_str());
@@ -775,7 +801,6 @@ void dlgDirectDbg::OnTargetComplete( wxCommandEvent & event )
         return;
 
     this->Show( true );
-    this->SetFocus();
 }
 
 ////////////////////////////////////////////////////////////////////////////////
