@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgClasses.cpp 8201 2010-03-04 19:56:17Z guillaume $
+// RCS-ID:      $Id: dlgClasses.cpp 8343 2010-05-07 15:15:51Z dpage $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -20,6 +20,7 @@
 #include "frm/frmMain.h"
 #include "db/pgConn.h"
 #include "schema/pgObject.h"
+#include "schema/pgDatabase.h"
 #include "utils/sysProcess.h"
 #include "frm/menu.h"
 #include "db/pgQueryThread.h"
@@ -292,7 +293,7 @@ void pgFrame::OnRecent(wxCommandEvent& event)
 
 
 
-void pgFrame::UpdateRecentFiles()
+void pgFrame::UpdateRecentFiles(bool updatefile)
 {
     if (!recentFileMenu)
         return;
@@ -313,7 +314,7 @@ void pgFrame::UpdateRecentFiles()
     while (i <= maxFiles)
         lastFiles[i++] = wxT("");
 
-    if (recentIndex > 1 && !lastPath.IsNull())
+    if (recentIndex > 1 && !lastPath.IsNull() && updatefile)
     {
         for (i=recentIndex ; i > 1 ; i--)
             lastFiles[i] = lastFiles[i-1];
@@ -331,7 +332,8 @@ void pgFrame::UpdateRecentFiles()
 
     for (i=1 ; i <= maxFiles ; i++)
     {
-        settings->Write(recentKey + wxString::Format(wxT("/%d"), i), lastFiles[i]);
+        if (updatefile)
+            settings->Write(recentKey + wxString::Format(wxT("/%d"), i), lastFiles[i]);
 
         if (!lastFiles[i].IsNull())
             recentFileMenu->Append(MNU_RECENT+i, wxT("&") + wxString::Format(wxT("%d"), i) + wxT("  ") + lastFiles[i]);
@@ -422,6 +424,9 @@ ExecutionDialog::ExecutionDialog(frmMain *frame, pgObject *_object) : DialogWith
     thread=0;
     object = _object;
     txtMessages = 0;
+
+    pgDatabase *db=object->GetDatabase();
+    conn = db->CreateConn();
 }
 
 void ExecutionDialog::EnableOK(const bool enable) 
@@ -433,6 +438,7 @@ void ExecutionDialog::EnableOK(const bool enable)
 void ExecutionDialog::OnClose(wxCloseEvent& event)
 {
     Abort();
+    delete conn;
     if (IsModal())
         EndModal(-1);
     else
@@ -454,6 +460,7 @@ void ExecutionDialog::OnCancel(wxCommandEvent& ev)
     }
     else
     {
+        delete conn;
         if (IsModal())
             EndModal(-1);
         else
@@ -488,7 +495,7 @@ void ExecutionDialog::OnOK(wxCommandEvent& ev)
 
         btnOK->Disable();
 
-        thread=new pgQueryThread(object->GetConnection(), sql);
+        thread=new pgQueryThread(conn, sql);
         if (thread->Create() != wxTHREAD_NO_ERROR)
         {
             Abort();
@@ -533,7 +540,7 @@ void ExecutionDialog::OnOK(wxCommandEvent& ev)
             else
             {
                 if (txtMessages)
-                    txtMessages->AppendText(object->GetConnection()->GetLastError());
+                    txtMessages->AppendText(conn->GetLastError());
                 Abort();
             }
         }
@@ -549,6 +556,7 @@ void ExecutionDialog::OnOK(wxCommandEvent& ev)
     else
     {
         Abort();
+        delete conn;
         Destroy();
     }
 }
@@ -639,8 +647,10 @@ void ExternProcessDialog::OnCancel(wxCommandEvent &ev)
 {
     if (process)
     {
-        btnCancel->Disable();
         Abort();
+        wxMilliSleep(100);
+        if (txtMessages)
+            txtMessages->AppendText(END_OF_LINE + wxString(_("Cancelled on user request.")) + END_OF_LINE + END_OF_LINE);
     }
     else
         pgDialog::OnCancel(ev);
