@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgColumn.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgColumn.cpp 8306 2010-04-28 13:00:46Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -321,7 +321,8 @@ wxString dlgColumn::GetSql()
 
             if (connection->BackendMinimumVersion(7, 5))
             {
-                if (cbDatatype->GetValue() != column->GetRawTypename() || 
+                if ((cbDatatype->GetValue() != column->GetRawTypename() && !column->GetIsArray()) ||
+                    (cbDatatype->GetValue() != column->GetRawTypename() + wxT("[]") && column->GetIsArray()) ||
                     (isVarLen && txtLength->IsEnabled() && StrToLong(len) != column->GetLength()) ||
                     (isVarPrec && txtPrecision->IsEnabled() && StrToLong(prec) != column->GetPrecision()))
                 {
@@ -491,7 +492,8 @@ void dlgColumn::CheckChange()
                     || txtDefault->GetValue() != column->GetDefault()
                     || txtComment->GetValue() != column->GetComment()
                     || chkNotNull->GetValue() != column->GetNotNull()
-                    || (cbDatatype->GetCount() > 1 && cbDatatype->GetGuessedStringSelection() != column->GetRawTypename())
+                    || (cbDatatype->GetCount() > 1 && cbDatatype->GetGuessedStringSelection() != column->GetRawTypename() && !column->GetIsArray())
+                    || (cbDatatype->GetCount() > 1 && cbDatatype->GetGuessedStringSelection() != column->GetRawTypename() + wxT("[]") && column->GetIsArray())
                     || (isVarLen && varlen != column->GetLength())
                     || (isVarPrec && varprec != column->GetPrecision())
                     || txtAttstattarget->GetValue() != NumToStr(column->GetAttstattarget());
