@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgDatabase.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgDatabase.cpp 8331 2010-05-05 16:23:36Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -11,7 +11,6 @@
 
 // wxWindows headers
 #include <wx/wx.h>
-#include <wx/generic/spinctlg.h>
 #include <wx/spinbutt.h>
 
 // App headers
@@ -105,7 +104,7 @@ int dlgDatabase::Go(bool modal)
     if (!database)
         cbOwner->Append(wxT(""));
 
-    AddGroups();
+    AddGroups(cbOwner);
     AddUsers(cbOwner);
 
     if (connection->BackendMinimumVersion(8, 0))
@@ -589,10 +588,16 @@ wxString dlgDatabase::GetSql()
             }
             if (oldVal != newVal)
             {
-                sql += wxT("ALTER DATABASE ") + qtIdent(name)
-                    +  wxT(" SET ") + newVar
-                    +  wxT("='") + newVal
-                    +  wxT("';\n");
+                if (newVar != wxT("search_path") && newVar != wxT("temp_tablespaces"))
+                    sql += wxT("ALTER DATABASE ") + qtIdent(name)
+                        +  wxT(" SET ") + newVar
+                        +  wxT("='") + newVal
+                        +  wxT("';\n");
+                else
+                    sql += wxT("ALTER DATABASE ") + qtIdent(name)
+                        +  wxT(" SET ") + newVar
+                        +  wxT("=") + newVal
+                        +  wxT(";\n");
             }
         }
         
