@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgFunction.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgFunction.cpp 8287 2010-04-20 22:13:46Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -177,7 +177,7 @@ int dlgFunction::Go(bool modal)
     if (!isBackendMinVer84)
         txtArgDefVal->Disable();
 
-    AddGroups();
+    AddGroups(cbOwner);
     AddUsers(cbOwner);
 
     lstArguments->AddColumn(_("Type"), 60);
@@ -983,10 +983,16 @@ wxString dlgFunction::GetSql()
             // changed, which will remove them all :-(
             if ((oldVal != newVal) || didChange)  
             {
-                sql += wxT("ALTER FUNCTION ") + name
-                    +  wxT(" SET ") + newVar
-                    +  wxT("='") + newVal
-                    +  wxT("';\n");
+                if (newVar != wxT("search_path") && newVar != wxT("temp_tablespaces"))
+                    sql += wxT("ALTER FUNCTION ") + name
+                        +  wxT(" SET ") + newVar
+                        +  wxT("='") + newVal
+                        +  wxT("';\n");
+                else
+                    sql += wxT("ALTER FUNCTION ") + name
+                        +  wxT(" SET ") + newVar
+                        +  wxT("=") + newVal
+                        +  wxT(";\n");
             }
         }
         
