@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgLanguage.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgLanguage.cpp 8258 2010-04-06 20:46:44Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -60,7 +60,7 @@ int dlgLanguage::Go(bool modal)
     if (!connection->BackendMinimumVersion(7, 5))
         txtComment->Disable();
 
-    AddGroups();
+    AddGroups(cbOwner);
     AddUsers(cbOwner);
     if (!connection->BackendMinimumVersion(8, 3))
         cbOwner->Disable();
