@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgPackage.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgPackage.cpp 8258 2010-04-06 20:46:44Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -65,7 +65,7 @@ int dlgPackage::Go(bool modal)
 
     cbOwner->Disable();
 
-    AddGroups();
+    AddGroups(cbOwner);
     AddUsers(cbOwner);
 
     if (package)
