@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgProperty.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgProperty.cpp 8258 2010-04-06 20:46:44Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -282,6 +282,7 @@ int dlgProperty::Go(bool modal)
     {
         if (!GetObject())
             cbOwner->Append(wxEmptyString);
+        AddGroups(cbowner);
         AddUsers(cbowner);
     }
     if (txtOid)
@@ -522,6 +523,19 @@ void dlgProperty::AddUsers(ctlComboBoxFix *cb1, ctlComboBoxFix *cb2)
 }
 
 
+void dlgProperty::AddGroups(ctlComboBoxFix *combo)
+{
+    if (connection->BackendMinimumVersion(8, 1))
+    {
+        FillCombobox(wxT("SELECT rolname FROM pg_roles WHERE NOT rolcanlogin ORDER BY 1"), combo);
+    }
+    else
+    {
+        FillCombobox(wxT("SELECT groname FROM pg_group ORDER BY 1"), combo);
+    }
+}
+
+
 void dlgProperty::PrepareTablespace(ctlComboBoxFix *cb, const OID current)
 {
     wxASSERT(cb != 0);
