@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgSchema.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgSchema.cpp 8258 2010-04-06 20:46:44Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -47,7 +47,7 @@ int dlgSchema::Go(bool modal)
     if (!schema)
         cbOwner->Append(wxT(""));
 
-    AddGroups();
+    AddGroups(cbOwner);
     AddUsers(cbOwner);
     if (schema)
     {
