@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgTable.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgTable.cpp 8258 2010-04-06 20:46:44Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -196,7 +196,7 @@ int dlgTable::Go(bool modal)
 {
     if (!table)
         cbOwner->Append(wxT(""));
-    AddGroups();
+    AddGroups(cbOwner);
     AddUsers(cbOwner);
     PrepareTablespace(cbTablespace);
 
