@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgTablespace.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgTablespace.cpp 8258 2010-04-06 20:46:44Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -56,7 +56,7 @@ int dlgTablespace::Go(bool modal)
 {
     if (!tablespace)
         cbOwner->Append(wxEmptyString);
-    AddGroups();
+    AddGroups(cbOwner);
     AddUsers(cbOwner);
 
     if (tablespace)
