@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgUser.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgUser.cpp 8287 2010-04-20 22:13:46Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -539,10 +539,16 @@ wxString dlgUser::GetSql()
         }
         if (oldVal != newVal)
         {
-            sql += wxT("ALTER USER ") + qtIdent(name)
-                +  wxT(" SET ") + newVar
-                +  wxT("='") + newVal
-                +  wxT("';\n");
+            if (newVar != wxT("search_path") && newVar != wxT("temp_tablespaces"))
+                sql += wxT("ALTER USER ") + qtIdent(name)
+                    +  wxT(" SET ") + newVar
+                    +  wxT("='") + newVal
+                    +  wxT("';\n");
+            else
+                sql += wxT("ALTER USER ") + qtIdent(name)
+                    +  wxT(" SET ") + newVar
+                    +  wxT("=") + newVal
+                    +  wxT(";\n");
         }
     }
     
