@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: events.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: events.cpp 8269 2010-04-16 21:06:20Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -139,6 +139,47 @@ void frmMain::OnClose(wxCloseEvent& event)
 }
 
 
+void frmMain::UpdateAllRecentFiles()
+{
+    wxWindow *fr;
+    windowList::Node *node;
+    node = frames.GetFirst();
+    while (node)
+    {
+        fr=node->GetData();
+        ((frmQuery*)fr)->UpdateRecentFiles(false);
+        node = node->GetNext();
+    }
+}
+
+
+void frmMain::UpdateAllFavouritesList()
+{
+    wxWindow *fr;
+    windowList::Node *node;
+    node = frames.GetFirst();
+    while (node)
+    {
+        fr=node->GetData();
+        ((frmQuery*)fr)->UpdateFavouritesList();
+        node = node->GetNext();
+    }
+}
+
+void frmMain::UpdateAllMacrosList()
+{
+    wxWindow *fr;
+    windowList::Node *node;
+    node = frames.GetFirst();
+    while (node)
+    {
+        fr=node->GetData();
+        ((frmQuery*)fr)->UpdateMacrosList();
+        node = node->GetNext();
+    }
+}
+
+
 void frmMain::OnAction(wxCommandEvent &ev)
 {
     actionFactory *af=menuFactories->GetFactory(ev.GetId());
