@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmBackupServer.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: frmBackupServer.cpp 8235 2010-03-19 10:30:41Z dpage $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -143,7 +143,7 @@ wxString frmBackupServer::getCmdPart1()
         cmd += wxT(" --host ") + server->GetName();
 
     cmd +=  wxT(" --port ") + NumToStr((long)server->GetPort())
-         +  wxT(" --username ") + server->GetUsername();
+         +  wxT(" --username ") + commandLineCleanOption(qtIdent(server->GetUsername()));
     return cmd;
 }
 
