@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmEditGrid.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: frmEditGrid.cpp 8331 2010-05-05 16:23:36Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -13,12 +13,6 @@
 #include <wx/wx.h>
 #include <wx/grid.h>
 
-#ifdef __WX_FULLSOURCE
-#include "wx/generic/gridsel.h"
-#else
-#include "ctl/wxgridsel.h"
-#endif
-
 // App headers
 #include "pgAdmin3.h"
 #include "utils/pgDefs.h"
@@ -480,6 +474,9 @@ void frmEditGrid::OnIncludeFilter(wxCommandEvent &event)
 {
     int curcol=sqlGrid->GetGridCursorCol();
     int currow=sqlGrid->GetGridCursorRow();
+
+    if (curcol == -1 || currow == -1)
+        return;
     
     sqlTable *table=sqlGrid->GetTable();
     wxString column_label = qtIdent(table->GetColLabelValueUnformatted(curcol));
@@ -522,6 +519,9 @@ void frmEditGrid::OnExcludeFilter(wxCommandEvent &event)
 {
     int curcol=sqlGrid->GetGridCursorCol();
     int currow=sqlGrid->GetGridCursorRow();
+
+    if (curcol == -1 || currow == -1)
+        return;
     
     sqlTable *table=sqlGrid->GetTable();
     wxString column_label = qtIdent(table->GetColLabelValueUnformatted(curcol));
@@ -571,6 +571,9 @@ void frmEditGrid::OnAscSort(wxCommandEvent &ev)
 {
     int curcol=sqlGrid->GetGridCursorCol();
 
+    if (curcol == -1)
+        return;
+
     sqlTable *table=sqlGrid->GetTable();
     wxString column_label = qtIdent(table->GetColLabelValueUnformatted(curcol));
     wxString old_sort_string = GetSortCols().Trim();
@@ -607,6 +610,9 @@ void frmEditGrid::OnAscSort(wxCommandEvent &ev)
 void frmEditGrid::OnDescSort(wxCommandEvent &ev)
 {
     int curcol=sqlGrid->GetGridCursorCol();
+
+    if (curcol == -1)
+       return;
     
     sqlTable *table=sqlGrid->GetTable();
     wxString column_label = qtIdent(table->GetColLabelValueUnformatted(curcol));
@@ -764,6 +770,10 @@ void frmEditGrid::OnKey(wxKeyEvent &event)
 {
     int curcol=sqlGrid->GetGridCursorCol();
     int currow=sqlGrid->GetGridCursorRow();
+
+    if (curcol == -1 || currow == -1)
+        return;
+
     int keycode=event.GetKeyCode();
     wxCommandEvent ev;
 
