@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmStatus.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: frmStatus.cpp 8352 2010-05-10 15:07:52Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -17,6 +17,7 @@
 #include <wx/image.h>
 #include <wx/textbuf.h>
 #include <wx/clipbrd.h>
+#include <wx/sysopt.h>
 
 // wxAUI
 #include <wx/aui/aui.h>
@@ -161,6 +162,9 @@ frmStatus::frmStatus(frmMain *form, const wxString& _title, pgConn *conn) : pgFr
     logHasTimestamp = false;
     logFormatKnown = false;
 
+    // Make the connection quiet on the logs
+    connection->ExecuteVoid(wxT("SET log_statement='none';SET log_duration='off';SET log_min_duration_statement=-1;"),false);
+
     // Notify wxAUI which frame to use
     manager.SetManagedWindow(this);
     manager.SetFlags(wxAUI_MGR_DEFAULT | wxAUI_MGR_TRANSPARENT_DRAG | wxAUI_MGR_ALLOW_ACTIVE_PANE);
@@ -403,7 +407,16 @@ void frmStatus::AddStatusPane()
     grdActivity->AddGrowableRow(0);
 
     // Add the list control
+#ifdef __WXMAC__
+    // Switch to the generic list control.
+    // Disable sort on Mac.
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), true);
+#endif
     wxListCtrl *lstStatus = new wxListCtrl(pnlActivity, CTL_STATUSLIST, wxDefaultPosition, wxDefaultSize, wxLC_REPORT|wxSUNKEN_BORDER);
+    // Now switch back
+#ifdef __WXMAC__
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), false);
+#endif
     grdActivity->Add(lstStatus, 0, wxGROW, 3);
 
     // Add the panel to the notebook
@@ -453,7 +466,16 @@ void frmStatus::AddLockPane()
     grdLock->AddGrowableRow(0);
 
     // Add the list control
+#ifdef __WXMAC__
+    // Switch to the generic list control.
+    // Disable sort on Mac.
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), true);
+#endif
     wxListCtrl *lstLocks = new wxListCtrl(pnlLock, CTL_LOCKLIST, wxDefaultPosition, wxDefaultSize, wxLC_REPORT|wxSUNKEN_BORDER);
+    // Now switch back
+#ifdef __WXMAC__
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), false);
+#endif
     grdLock->Add(lstLocks, 0, wxGROW, 3);
 
     // Add the panel to the notebook
@@ -501,7 +523,16 @@ void frmStatus::AddXactPane()
     grdXacts->AddGrowableRow(0);
 
     // Add the list control
+#ifdef __WXMAC__
+    // Switch to the generic list control.
+    // Disable sort on Mac.
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), true);
+#endif
     wxListCtrl *lstXacts = new wxListCtrl(pnlXacts, CTL_LOCKLIST, wxDefaultPosition, wxDefaultSize, wxLC_REPORT|wxSUNKEN_BORDER);
+    // Now switch back
+#ifdef __WXMAC__
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), false);
+#endif
     grdXacts->Add(lstXacts, 0, wxGROW, 3);
 
     // Add the panel to the notebook
@@ -560,7 +591,16 @@ void frmStatus::AddLogPane()
     grdLog->AddGrowableRow(0);
 
     // Add the list control
+#ifdef __WXMAC__
+    // Switch to the generic list control.
+    // Disable sort on Mac.
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), true);
+#endif
     wxListCtrl *lstLog = new wxListCtrl(pnlLog, CTL_LOGLIST, wxDefaultPosition, wxDefaultSize, wxLC_REPORT|wxSUNKEN_BORDER);
+    // Now switch back
+#ifdef __WXMAC__
+    wxSystemOptions::SetOption(wxT("mac.listctrl.always_use_generic"), false);
+#endif
     grdLog->Add(lstLog, 0, wxGROW, 3);
     
     // Add the panel to the notebook
@@ -967,8 +1007,6 @@ void frmStatus::OnRefreshStatusTimer(wxTimerEvent &event)
     
     wxCriticalSectionLocker lock(gs_critsect);
 
-    connection->ExecuteVoid(wxT("SET log_statement='none';SET log_duration='off';"),false);
-
     long row=0;
     pgSet *dataSet1=connection->ExecuteSet(wxT("SELECT *,(SELECT min(pid) FROM pg_locks l1 WHERE GRANTED AND relation IN (SELECT relation FROM pg_locks l2 WHERE l2.pid=procpid AND NOT granted)) AS blockedby FROM pg_stat_activity ORDER BY procpid"));
     if (dataSet1)
@@ -1076,8 +1114,6 @@ void frmStatus::OnRefreshLocksTimer(wxTimerEvent &event)
     
     wxCriticalSectionLocker lock(gs_critsect);
 
-    connection->ExecuteVoid(wxT("SET log_statement='none';SET log_duration='off';"),false);
-
     long row=0;
     wxString sql;
     if (connection->BackendMinimumVersion(8, 3)) 
@@ -1224,8 +1260,6 @@ void frmStatus::OnRefreshXactTimer(wxTimerEvent &event)
     
     wxCriticalSectionLocker lock(gs_critsect);
 
-    connection->ExecuteVoid(wxT("SET log_statement='none';SET log_duration='off';"),false);
-
     long row=0;
     wxString sql = wxT("SELECT * FROM pg_prepared_xacts");
 
@@ -1309,8 +1343,6 @@ void frmStatus::OnRefreshLogTimer(wxTimerEvent &event)
     
     wxCriticalSectionLocker lock(gs_critsect);
 
-    connection->ExecuteVoid(wxT("SET log_statement='none';SET log_duration='off';"),false);
-
     if (connection->GetLastResultError().sql_state == wxT("42501"))
     {
         // Don't have superuser privileges, so can't do anything with the log display
