@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: gqbBrowser.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: gqbBrowser.cpp 8267 2010-04-15 21:46:31Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -127,8 +127,13 @@ void gqbBrowser::OnBeginDrag(wxTreeEvent& event)
         if(result==wxDragCopy)
         {
             controller->getView()->CalcUnscrolledPosition(xx,yy,&xx,&yy);
-            controller->addTableToModel(item,wxPoint(xx,yy));
+            gqbQueryObject* queryObj = controller->addTableToModel(item,wxPoint(xx,yy));
             controller->getView()->Refresh();
+            if (queryObj)
+            {
+                controller->getView()->Update();
+                controller->getView()->updateModelSize(queryObj, false);
+            }
         }
     }
 }
