@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgClasses.h 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: dlgClasses.h 8269 2010-04-16 21:06:20Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -61,6 +61,8 @@ public:
     void OnAction(wxCommandEvent& event);
 	menuFactoryList *GetMenuFactories() { return menuFactories; }
 
+    void UpdateRecentFiles(bool updatefile=true);
+
 protected:
 
     void OnKeyDown(wxKeyEvent& event);
@@ -72,8 +74,6 @@ protected:
     virtual bool CheckChanged(bool canVeto) { return false; }
     virtual wxString GetHelpPage() const { return wxEmptyString; }
 
-    void UpdateRecentFiles();
-
     windowList frames;
     menuFactoryList *menuFactories;
     wxString dlgName;
@@ -119,6 +119,7 @@ protected:
 
     void EnableOK(const bool enable);
 
+    pgConn *conn;
     pgObject *object;
     pgQueryThread *thread;
     wxTextCtrl *txtMessages;
