@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: misc.h 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: misc.h 8235 2010-03-19 10:30:41Z dpage $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -244,14 +244,11 @@ enum        // depends on pgaFactory::addImage order!
     PGICON_PUBLIC
 };
 
+// File/directory name cleanup
+wxString sanitizePath(const wxString &path);
+wxString commandLineCleanOption(const wxString &option, bool schemaObject = false);
+
 #endif // PGSCLI
 
 #endif
 
-#if !defined(PGSCLI)
-
-// File/directory name cleanup
-wxString sanitizePath(const wxString &path);
-wxString commandLineCleanOption(const wxString &option);
-
-#endif // PGSCLI
