@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: edbPackage.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: edbPackage.cpp 8345 2010-05-07 15:40:17Z dpage $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -26,11 +26,20 @@ edbPackage::edbPackage(pgSchema *newSchema, const wxString& newName)
 
 bool edbPackage::IsUpToDate()
 {
-    wxString sql = wxT("SELECT xmin FROM edb_package WHERE oid = ") + this->GetOidStr();
-	if (!this->GetDatabase()->GetConnection() || this->GetDatabase()->ExecuteScalar(sql) != NumToStr(GetXid()))
-		return false;
-	else
-		return true;
+    pgConn *conn = GetDatabase()->GetConnection();
+    if (!conn)
+        return false;
+
+    wxString sql;
+    if(conn->EdbMinimumVersion(8, 2))
+        sql = wxT("SELECT xmin FROM pg_namespace WHERE oid = ") + this->GetOidStr();
+    else
+        sql = wxT("SELECT xmin FROM edb_package WHERE oid = ") + this->GetOidStr();
+
+    if (conn->ExecuteScalar(sql) != NumToStr(GetXid()))
+        return false;
+    else
+        return true;
 }
 
 bool edbPackage::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
