@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgColumn.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgColumn.cpp 8312 2010-04-29 16:45:30Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -102,11 +102,10 @@ wxString pgColumn::GetSql(ctlTree *browser)
                     + wxT(" DROP COLUMN ") + GetQuotedIdentifier() + wxT(";")
                     
                     + wxT("\n\nALTER TABLE ") + GetQuotedFullTable()
-                    + wxT(" ADD COLUMN ") + GetQuotedIdentifier() + wxT(" ") + GetQuotedTypename()
+                    + wxT(" ADD COLUMN ") + GetQuotedIdentifier() + wxT(" ")
+                    + GetQuotedTypename() + wxT(";\n");
                     
-                    + wxT(";\nALTER TABLE ")+ GetQuotedFullTable()
-                    + wxT(" ALTER COLUMN ") + GetQuotedIdentifier()
-                    + wxT(" SET STORAGE ") + GetStorage() + wxT(";\n");
+                sql += GetStorageSql();
 
                 if (GetNotNull())
                     sql += wxT("ALTER TABLE ") + GetQuotedFullTable()
@@ -116,10 +115,7 @@ wxString pgColumn::GetSql(ctlTree *browser)
                     sql += wxT("ALTER TABLE ") + GetQuotedFullTable()
                         + wxT(" ALTER COLUMN ") + GetQuotedIdentifier()
                         + wxT(" SET DEFAULT ") + GetDefault() + wxT(";\n");
-                if (GetAttstattarget() >= 0)
-                    sql += wxT("ALTER TABLE ") + GetQuotedFullTable()
-                        + wxT(" ALTER COLUMN ") + GetQuotedIdentifier()
-                        + wxT(" SET STATISTICS ") + NumToStr(GetAttstattarget()) + wxT(";\n");
+                sql += GetAttstattargetSql();
 
                 sql += GetCommentSql();
 
@@ -143,6 +139,30 @@ wxString pgColumn::GetCommentSql()
     return commentSql;
 }
 
+wxString pgColumn::GetStorageSql()
+{
+    wxString storageSql;
+
+    if (GetStorage() != GetDefaultStorage())
+        storageSql = wxT("ALTER TABLE ")+ GetQuotedFullTable()
+                    + wxT(" ALTER COLUMN ") + GetQuotedIdentifier()
+                    + wxT(" SET STORAGE ") + GetStorage() + wxT(";\n");
+    
+    return storageSql;
+}
+
+wxString pgColumn::GetAttstattargetSql()
+{
+    wxString attstattargetSql;
+
+    if (GetAttstattarget() >= 0)
+        attstattargetSql = wxT("ALTER TABLE ") + GetQuotedFullTable()
+                         + wxT(" ALTER COLUMN ") + GetQuotedIdentifier()
+                         + wxT(" SET STATISTICS ") + NumToStr(GetAttstattarget()) + wxT(";\n");
+    
+    return attstattargetSql;
+}
+
 wxString pgColumn::GetPrivileges()
 {
     wxString privileges;
@@ -370,7 +390,7 @@ pgObject *pgColumnFactory::CreateObjects(pgCollection *coll, ctlTree *browser, c
         
     wxString sql=
         wxT("SELECT att.*, def.*, pg_catalog.pg_get_expr(def.adbin, def.adrelid) AS defval, CASE WHEN att.attndims > 0 THEN 1 ELSE 0 END AS isarray, format_type(ty.oid,NULL) AS typname, format_type(ty.oid,att.atttypmod) AS displaytypname, tn.nspname as typnspname, et.typname as elemtypname,\n")
-        wxT("  cl.relname, na.nspname, att.attstattarget, description, cs.relname AS sername, ns.nspname AS serschema,\n")
+        wxT("  ty.typstorage AS defaultstorage, cl.relname, na.nspname, att.attstattarget, description, cs.relname AS sername, ns.nspname AS serschema,\n")
         wxT("  (SELECT count(1) FROM pg_type t2 WHERE t2.typname=ty.typname) > 1 AS isdup, indkey,\n")
         wxT("  CASE \n")
         wxT("       WHEN EXISTS( SELECT inhparent FROM pg_inherits WHERE inhrelid=att.attrelid )\n")
@@ -428,6 +448,12 @@ pgObject *pgColumnFactory::CreateObjects(pgCollection *coll, ctlTree *browser, c
                 storage == wxT("e") ? wxT("EXTERNAL") :
                 storage == wxT("m") ? wxT("MAIN") :
                 storage == wxT("x") ? wxT("EXTENDED") : wxT("Unknown"));
+            wxString defaultStorage=columns->GetVal(wxT("defaultstorage"));
+            column->iSetDefaultStorage(
+                defaultStorage == wxT("p") ? wxT("PLAIN") :
+                defaultStorage == wxT("e") ? wxT("EXTERNAL") :
+                defaultStorage == wxT("m") ? wxT("MAIN") :
+                defaultStorage == wxT("x") ? wxT("EXTENDED") : wxT("Unknown"));
 
             column->iSetTyplen(columns->GetLong(wxT("attlen")));
 
