@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatabase.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgDatabase.cpp 8287 2010-04-20 22:13:46Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -348,7 +348,7 @@ wxString pgDatabase::GetSql(ctlTree *browser)
             + wxT("\n\nCREATE DATABASE ") + GetQuotedIdentifier()
             + wxT("\n  WITH OWNER = ") + qtIdent(GetOwner())
             + wxT("\n       ENCODING = ") + qtDbString(GetEncoding());
-        if (tablespace != defaultTablespace)
+        if (!GetTablespace().IsEmpty())
             sql += wxT("\n       TABLESPACE = ") + qtIdent(GetTablespace());
         if (myConn && myConn->BackendMinimumVersion(8, 4))
         {
@@ -364,8 +364,15 @@ wxString pgDatabase::GetSql(ctlTree *browser)
 
         size_t i;
         for (i=0 ; i < variables.GetCount() ; i++)
-            sql += wxT("ALTER DATABASE ") + GetQuotedFullIdentifier()
-                + wxT(" SET ") + variables.Item(i).BeforeFirst('=') + wxT("='") + variables.Item(i).AfterFirst('=') + wxT("';\n");
+        {
+            if (variables.Item(i).BeforeFirst('=') != wxT("search_path") &&
+                variables.Item(i).BeforeFirst('=') != wxT("temp_tablespaces"))
+                sql += wxT("ALTER DATABASE ") + GetQuotedFullIdentifier()
+                    + wxT(" SET ") + variables.Item(i).BeforeFirst('=') + wxT("='") + variables.Item(i).AfterFirst('=') + wxT("';\n");
+            else
+                sql += wxT("ALTER DATABASE ") + GetQuotedFullIdentifier()
+                    + wxT(" SET ") + variables.Item(i).BeforeFirst('=') + wxT("=") + variables.Item(i).AfterFirst('=') + wxT(";\n");
+        }
 
 		if (myConn)
 		{
@@ -743,14 +750,25 @@ void pgDatabaseCollection::ShowStatistics(frmMain *form, ctlListView *statistics
 
     bool hasSize=GetConnection()->HasFeature(FEATURE_SIZE);
 
-    wxString sql=wxT("SELECT datname, numbackends, xact_commit, xact_rollback, blks_read, blks_hit");
+    wxString restr;
+    if (!GetServer()->GetDbRestriction().IsEmpty())
+    {
+        if (restr.IsEmpty())
+            restr = wxT(" WHERE datname IN (");
+        else
+            restr = wxT("   AND datname IN (");
+
+        restr += GetServer()->GetDbRestriction() + wxT(")\n");
+    }
+    
+    wxString sql=wxT("SELECT datid, datname, numbackends, xact_commit, xact_rollback, blks_read, blks_hit");
 
 	if (GetConnection()->BackendMinimumVersion(8,3))
 		sql += wxT(", tup_returned, tup_fetched, tup_inserted, tup_updated, tup_deleted");
     if (hasSize)
         sql += wxT(", pg_size_pretty(pg_database_size(datid)) as size");
 
-    sql += wxT("\n  FROM pg_stat_database db ORDER BY datname");
+    sql += wxT("\n  FROM pg_stat_database db\n") + restr + wxT(" ORDER BY datname");
 
     // Add the statistics view columns
     statistics->ClearAll();
@@ -771,27 +789,36 @@ void pgDatabaseCollection::ShowStatistics(frmMain *form, ctlListView *statistics
 		statistics->AddColumn(_("Tuples Deleted"), 60);
 	}
 
+    bool sysobj;
     pgSet *stats = GetServer()->ExecuteSet(sql);
     if (stats)
     {
         while (!stats->Eof())
         {
-            statistics->InsertItem(stats->CurrentPos() - 1, stats->GetVal(wxT("datname")), PGICON_STATISTICS);
-            statistics->SetItem(stats->CurrentPos() - 1, 1, stats->GetVal(wxT("numbackends")));
-            if (hasSize)
-                statistics->SetItem(stats->CurrentPos() - 1, 2, stats->GetVal(wxT("size")));
-			statistics->SetItem(stats->CurrentPos() - 1, 2 + (hasSize?1:0), stats->GetVal(wxT("xact_commit")));
-            statistics->SetItem(stats->CurrentPos() - 1, 3 + (hasSize?1:0), stats->GetVal(wxT("xact_rollback")));
-            statistics->SetItem(stats->CurrentPos() - 1, 4 + (hasSize?1:0), stats->GetVal(wxT("blks_read")));
-            statistics->SetItem(stats->CurrentPos() - 1, 5 + (hasSize?1:0), stats->GetVal(wxT("blks_hit")));
-			if (GetConnection()->BackendMinimumVersion(8,3))
-			{
-				statistics->SetItem(stats->CurrentPos()-1, 6 + (hasSize?1:0), stats->GetVal(wxT("tup_returned")));
-				statistics->SetItem(stats->CurrentPos()-1, 7 + (hasSize?1:0), stats->GetVal(wxT("tup_fetched")));
-				statistics->SetItem(stats->CurrentPos()-1, 8 + (hasSize?1:0), stats->GetVal(wxT("tup_inserted")));
-				statistics->SetItem(stats->CurrentPos()-1, 9 + (hasSize?1:0), stats->GetVal(wxT("tup_updated")));
-				statistics->SetItem(stats->CurrentPos()-1, 10 + (hasSize?1:0), stats->GetVal(wxT("tup_deleted")));
-			}
+            if (stats->GetVal(wxT("datname")) == wxT("template0"))
+                sysobj = true;
+            else
+                sysobj = stats->GetOid(wxT("datid")) <= GetServer()->GetLastSystemOID();
+
+            if (settings->GetShowSystemObjects() || !sysobj)
+            {
+                statistics->InsertItem(statistics->GetItemCount(), stats->GetVal(wxT("datname")), PGICON_STATISTICS);
+                statistics->SetItem(statistics->GetItemCount() - 1, 1, stats->GetVal(wxT("numbackends")));
+                if (hasSize)
+                    statistics->SetItem(statistics->GetItemCount() - 1, 2, stats->GetVal(wxT("size")));
+			    statistics->SetItem(statistics->GetItemCount() - 1, 2 + (hasSize?1:0), stats->GetVal(wxT("xact_commit")));
+                statistics->SetItem(statistics->GetItemCount() - 1, 3 + (hasSize?1:0), stats->GetVal(wxT("xact_rollback")));
+                statistics->SetItem(statistics->GetItemCount() - 1, 4 + (hasSize?1:0), stats->GetVal(wxT("blks_read")));
+                statistics->SetItem(statistics->GetItemCount() - 1, 5 + (hasSize?1:0), stats->GetVal(wxT("blks_hit")));
+			    if (GetConnection()->BackendMinimumVersion(8,3))
+			    {
+			    	statistics->SetItem(statistics->GetItemCount() - 1, 6 + (hasSize?1:0), stats->GetVal(wxT("tup_returned")));
+			    	statistics->SetItem(statistics->GetItemCount() - 1, 7 + (hasSize?1:0), stats->GetVal(wxT("tup_fetched")));
+			    	statistics->SetItem(statistics->GetItemCount() - 1, 8 + (hasSize?1:0), stats->GetVal(wxT("tup_inserted")));
+			    	statistics->SetItem(statistics->GetItemCount() - 1, 9 + (hasSize?1:0), stats->GetVal(wxT("tup_updated")));
+			    	statistics->SetItem(statistics->GetItemCount() - 1, 10 + (hasSize?1:0), stats->GetVal(wxT("tup_deleted")));
+			    }
+            }
             stats->MoveNext();
         }
 
