@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgFunction.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgFunction.cpp 8334 2010-05-05 18:12:51Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -141,8 +141,15 @@ wxString pgFunction::GetSql(ctlTree *browser)
 
         size_t i;
         for (i=0 ; i < configList.GetCount() ; i++)
-            sql += wxT("\nALTER FUNCTION ") + qtSig
-                + wxT(" SET ") + configList.Item(i).BeforeFirst('=') + wxT("='") + configList.Item(i).AfterFirst('=') + wxT("';\n");
+        {
+            if (configList.Item(i).BeforeFirst('=') != wxT("search_path") &&
+                configList.Item(i).BeforeFirst('=') != wxT("temp_tablespaces"))
+                sql += wxT("\nALTER FUNCTION ") + qtSig
+                    + wxT(" SET ") + configList.Item(i).BeforeFirst('=') + wxT("='") + configList.Item(i).AfterFirst('=') + wxT("';\n");
+            else
+                sql += wxT("\nALTER FUNCTION ") + qtSig
+                    + wxT(" SET ") + configList.Item(i).BeforeFirst('=') + wxT("=") + configList.Item(i).AfterFirst('=') + wxT(";\n");
+        }
 
         sql += wxT("\n")
             +  GetOwnerSql(8, 0, wxT("FUNCTION ") + qtSig)
@@ -576,8 +583,7 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
 
             wxString strReturnTableArgs;
             // Process default values
-            if (obj->GetConnection()->BackendMinimumVersion(8, 4) &&
-                function->GetArgCount() != 0)
+            if (obj->GetConnection()->BackendMinimumVersion(8, 4))
             {
                 size_t currINindex = 0;
                 for (size_t index = 0; index < function->GetArgModesArray().Count(); index++)
@@ -592,6 +598,8 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
                         {
                             if (argDefValArray[currINindex++] != wxT("-"))
                                 function->iAddArgDef(argDefValArray[currINindex-1]);
+                            else
+                                function->iAddArgDef(wxT(""));
                         }
                         else
                             function->iAddArgDef(wxEmptyString);
@@ -612,7 +620,10 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
 
             function->iSetOid(functions->GetOid(wxT("oid")));
             function->iSetXid(functions->GetOid(wxT("xmin")));
-            function->UpdateSchema(browser, functions->GetOid(wxT("pronamespace")));
+			if (browser)
+	            function->UpdateSchema(browser, functions->GetOid(wxT("pronamespace")));
+			else
+				return 0;
             function->iSetOwner(functions->GetVal(wxT("funcowner")));
             function->iSetAcl(functions->GetVal(wxT("proacl")));
             wxString strType = functions->GetVal(wxT("typname"));
