@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgGroup.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgGroup.cpp 8283 2010-04-20 17:09:11Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -33,7 +33,7 @@ wxString pgGroup::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
-        sql = wxT("-- Group: \"") + GetName() + wxT("\"\n\n")
+        sql = wxT("-- Group: ") + GetName() + wxT("\n\n")
             + wxT("DROP GROUP ") + GetQuotedFullIdentifier() + wxT(";")
             + wxT("\n\nCREATE Group ") + GetQuotedIdentifier()
             + wxT("\n  WITH SYSID ") + NumToStr(groupId)
