@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgObject.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgObject.cpp 8334 2010-05-05 18:12:51Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -1085,7 +1085,10 @@ void pgSchemaObject::SetSchema(pgSchema *newSchema)
 
 void pgSchemaObject::UpdateSchema(ctlTree *browser, OID schemaOid)
 {
-    // used e.g. for triggers that use trigger functions from other namespaces
+	// used e.g. for triggers that use trigger functions from other namespaces
+
+	if (!browser)
+		return;
 
     if (schema->GetOid() != schemaOid)
     {
