@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgOperatorFamily.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgOperatorFamily.cpp 8283 2010-04-20 17:09:11Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -40,7 +40,7 @@ wxString pgOperatorFamily::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
-        sql = wxT("-- Operator Family: \"") + GetName() + wxT("\"\n\n")
+        sql = wxT("-- Operator Family: ") + GetName() + wxT("\n\n")
             + wxT("-- DROP OPERATOR FAMILY ") + GetQuotedFullIdentifier() + wxT(" USING ") + GetAccessMethod() + wxT(";")
             + wxT("\n\nCREATE OPERATOR FAMILY ") + GetQuotedFullIdentifier()
             + wxT(" USING ") + GetAccessMethod()
