@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgRole.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgRole.cpp 8287 2010-04-20 22:13:46Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -71,7 +71,7 @@ wxString pgRole::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
-        sql = wxT("-- Role: \"") + GetName() + wxT("\"\n\n")
+        sql = wxT("-- Role: ") + GetName() + wxT("\n\n")
             + wxT("-- DROP ROLE ") + GetQuotedFullIdentifier() + wxT(";")
             + wxT("\n\nCREATE ROLE ") + GetQuotedIdentifier();
 
@@ -104,8 +104,13 @@ wxString pgRole::GetSql(ctlTree *browser)
         size_t index;
         for (index=0 ; index < configList.GetCount() ; index++)
         {
-            sql += wxT("ALTER ROLE ") + GetQuotedIdentifier()
-                + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("='") + configList.Item(index).AfterFirst('=') + wxT("';\n");
+            if (configList.Item(index).BeforeFirst('=') != wxT("search_path") &&
+                configList.Item(index).BeforeFirst('=') != wxT("temp_tablespaces"))
+                sql += wxT("ALTER ROLE ") + GetQuotedIdentifier()
+                    + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("='") + configList.Item(index).AfterFirst('=') + wxT("';\n");
+            else
+                sql += wxT("ALTER ROLE ") + GetQuotedIdentifier()
+                    + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("=") + configList.Item(index).AfterFirst('=') + wxT(";\n");
         }
         for (index=0 ; index < rolesIn.GetCount() ; index++)
         {
