@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgSchema.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgSchema.cpp 8283 2010-04-20 17:09:11Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -154,9 +154,9 @@ wxString pgSchemaBase::GetSql(ctlTree *browser)
     if (sql.IsNull())
     {
         if (GetMetaType() == PGM_CATALOG)
-            sql = wxT("-- Catalog: \"") + GetName() + wxT("\"\n\n");
+            sql = wxT("-- Catalog: ") + GetName() + wxT("\n\n");
         else
-            sql = wxT("-- Schema: \"") + GetName() + wxT("\"\n\n");
+            sql = wxT("-- Schema: ") + GetName() + wxT("\n\n");
 
         sql += wxT("-- DROP SCHEMA ") + GetQuotedFullIdentifier() + wxT(";")
             + wxT("\n\nCREATE SCHEMA ") + qtIdent(GetName()) 
