@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTable.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgTable.cpp 8250 2010-04-03 09:41:28Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -276,8 +276,15 @@ wxString pgTable::GetSql(ctlTree *browser)
                     prevComment = column->GetComment();
 
                     // Whilst we are looping round the columns, grab their comments as well.
-                    // Perhaps we should also get storage types here?
                     colDetails += column->GetCommentSql();
+                    if (colDetails.Length() > 0)
+                        if (colDetails.Last() != '\n')
+                            colDetails += wxT("\n");
+                    colDetails += column->GetStorageSql();
+                    if (colDetails.Length() > 0)
+                        if (colDetails.Last() != '\n')
+                            colDetails += wxT("\n");
+                    colDetails += column->GetAttstattargetSql();
                     if (colDetails.Length() > 0)
                         if (colDetails.Last() != '\n')
                             colDetails += wxT("\n");
