@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgTablespace.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgTablespace.cpp 8283 2010-04-20 17:09:11Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -86,7 +86,7 @@ wxString pgTablespace::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
-        sql = wxT("-- Tablespace: \"") + GetName() + wxT("\"\n\n");
+        sql = wxT("-- Tablespace: ") + GetName() + wxT("\n\n");
         if (location.IsEmpty())
             sql += wxT("-- System Tablespace\n");
         else
