@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgUser.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgUser.cpp 8287 2010-04-20 22:13:46Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -45,7 +45,7 @@ wxString pgUser::GetSql(ctlTree *browser)
 {
     if (sql.IsNull())
     {
-        sql = wxT("-- User: \"") + GetName() + wxT("\"\n\n")
+        sql = wxT("-- User: ") + GetName() + wxT("\n\n")
             + wxT("-- DROP USER ") + GetQuotedFullIdentifier() + wxT(";")
             + wxT("\n\nCREATE USER ") + GetQuotedIdentifier()
             + wxT("\n  WITH SYSID ") + NumToStr(userId);
@@ -63,8 +63,13 @@ wxString pgUser::GetSql(ctlTree *browser)
         size_t index;
         for (index=0 ; index < configList.GetCount() ; index++)
         {
-            sql += wxT("ALTER USER ") + GetQuotedIdentifier()
-                + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("='") + configList.Item(index).AfterFirst('=') + wxT("';\n");
+            if (configList.Item(index).BeforeFirst('=') != wxT("search_path") &&
+                configList.Item(index).BeforeFirst('=') != wxT("temp_tablespaces"))
+                sql += wxT("ALTER USER ") + GetQuotedIdentifier()
+                    + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("='") + configList.Item(index).AfterFirst('=') + wxT("';\n");
+            else
+                sql += wxT("ALTER USER ") + GetQuotedIdentifier()
+                    + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("=") + configList.Item(index).AfterFirst('=') + wxT(";\n");
         }
         for (index=0 ; index < groupsIn.GetCount() ; index++)
             sql += wxT("ALTER GROUP ") + qtIdent(groupsIn.Item(index))
