@@ -1,7 +1,7 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgView.cpp 8187 2010-02-25 21:54:35Z dpage $
+// RCS-ID:      $Id: pgView.cpp 8264 2010-04-10 07:47:43Z guillaume $
 // Copyright (C) 2002 - 2010, The pgAdmin Development Team
 // This software is released under the PostgreSQL Licence
 //
@@ -108,6 +108,8 @@ wxString pgView::GetSql(ctlTree *browser)
             if (!comments.IsEmpty())
                 sql += comments + wxT("\n");
         }
+
+        AppendStuff(sql, browser, ruleFactory);
     }
     return sql;
 }
@@ -258,6 +260,33 @@ void pgView::ShowHint(frmMain *form, bool force)
     frmHint::ShowHint((wxWindow *)form, hints, GetFullIdentifier(), force);
 }
 
+void pgView::AppendStuff(wxString &sql, ctlTree *browser, pgaFactory &factory)
+{
+    wxString tmp;
+
+    pgCollection *collection=browser->FindCollection(factory, GetId());
+    if (collection)
+    {
+        tmp += wxT("\n");
+        collection->ShowTreeDetail(browser);
+
+        treeObjectIterator idxIt(browser, collection);
+        pgObject *obj;
+        while ((obj = idxIt.GetNextObject()) != 0)
+        {
+            if (obj->GetName() != wxT("_RETURN"))
+            {
+                obj->ShowTreeDetail(browser);
+
+                tmp += obj->GetSql(browser) + wxT("\n");
+            }
+        }
+    }
+
+    if (!tmp.IsEmpty() && tmp != wxT("\n"))
+        sql += tmp;
+}
+
 ///////////////////////////////////////////////////////
 
 
